==> haskell-parsers-0.12.12-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-HtzRWL4JBX8EP2VBspy4KU
key:                  parsers-0.12.12-HtzRWL4JBX8EP2VBspy4KU
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  15ebba879ab8e36b84b34ee79dccb401
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-HtzRWL4JBX8EP2VBspy4KU
depends:
    attoparsec-0.14.4-4euoXrooDbuLZe6Xn3rp2d base-4.17.2.1
    binary-0.8.9.1 charset-0.3.12-6JETPIQNbbbIus40RIh7nM
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-GtjUIC3j80u95XeMq22yYk text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.12-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-9Z8RyRYYd1ErrYjYlkxDN
key:                  parsers-0.12.12-9Z8RyRYYd1ErrYjYlkxDN
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  ce753d5c0d959d4777d98be0ce675e67
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-9Z8RyRYYd1ErrYjYlkxDN
depends:
    attoparsec-0.14.4-IjP3u1baQ7d7AdktrTB8o9 base-4.17.2.1
    binary-0.8.9.1 charset-0.3.12-8jpbyLvpzkx4IWIqXfpBS3
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-APNnjCxblnoKMeXmBXkKkr text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
